@@ -2,7 +2,7 @@ from scipy import stats
 from scipy.stats import trim_mean
 import pandas as pd
 import numpy as np
-
+from numpy.random import random
 
 
 class PD_input:
@@ -126,7 +126,7 @@ class PD_input:
         self.input_file = result_df
         return result_df
 
-    def baseline_correction_peptide_return(self,input_file,threshold=5,i_baseline=0):#TODO Make available for together analyzed data
+    def baseline_correction_peptide_return(self,input_file,threshold=5,i_baseline=0,random=None):#TODO Make available for together analyzed data
         print("Baseline correction")
         channels=[col for col in input_file.columns if 'Abundance:' in col]
         MPA = [col for col in input_file.columns if 'Master Protein Accessions' in col]
@@ -139,8 +139,10 @@ class PD_input:
         temp_data[channels]=temp_data[channels].subtract(baseline,axis='index')
         temp_data['Mean']=temp_data[channels].mean(axis=1)
         
-        
-        temp_data[temp_data < 0]=0 # replace negative abundances with 0
+        if random is None:
+            temp_data[temp_data < 0]=0 # replace negative abundances with 0
+        else:
+            temp_data = np.where(temp_data < 0, random(size=len(temp_data)))
         temp_data=temp_data.loc[temp_data['Mean'] > threshold] # set S/N threshold for each PSM
         input_file[channels]=temp_data[channels]
         return input_file
@@ -452,7 +454,7 @@ class plain_text_input:
         print("Combination done")
         return protein_df[channels]
 
-    def baseline_correction_peptide_return(self,input_file,threshold=5,i_baseline=0):#TODO Make available for together analyzed data
+    def baseline_correction_peptide_return(self,input_file,threshold=5,i_baseline=0,random=None):#TODO Make available for together analyzed data
         print("Baseline correction")
         channels=self.abundances
         MPA = self.mpa
@@ -466,8 +468,10 @@ class plain_text_input:
         temp_data[channels]=temp_data[channels].subtract(baseline,axis='index')
         temp_data['Mean']=temp_data[channels].mean(axis=1)
         
-        
-        temp_data[temp_data < 0]=0 # replace negative abundances with 0
+        if random is None:
+            temp_data[temp_data < 0]=0 # replace negative abundances with 0
+        else:
+            temp_data = np.where(temp_data < 0, random(size=len(temp_data)))
         temp_data=temp_data.loc[temp_data['Mean'] > threshold] # set S/N threshold for each PSM
         input_file[channels]=temp_data[channels]
         return input_file
